#!/usr/bin/perl -w 
###############################################################################
#   afick_common.pl
#      it's a part of the afick project
#
#    Copyright (C) 2002-2004 by Eric Gerbier
#    Bug reports to: gerbier@users.sourceforge.net
#    $Id: afick-common.pl 3589 2015-04-25 07:12:28Z gerbier $
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
###############################################################################
# common sub and var for afick's tool
###############################################################################
# I use special naming for references :
# $r_name : for a ref to scalar
# $rh_name : for a ref to hashes
# $ra_name : for a ref to array

use strict;
use warnings;

use English qw(-no_match_vars);
use POSIX qw(strftime);
use File::Basename;

use Data::Dumper;

###############################################################################
# where are installed afick modules (.pm)
# will be used to load packages
# and for auto-control
sub get_module_dir() {

	my $module_dir = dirname($PROGRAM_NAME) . '/lib';
	my $linux_dir  = '/usr/lib/afick/lib';
	if ( -e $module_dir ) {

		# for windows and tests
		return $module_dir;
	}
	elsif ( -d $linux_dir ) {

		# for linux
		return $linux_dir;
	}
	else {

		# ?
		return 'lib';
	}
}
##########################################################################
# load libraries
my $module_dir = get_module_dir();
push @INC, $module_dir;

my @modules = (
	'Afick::Constant',
	'Afick::Msg',
	'Afick::Lock',
	'Afick::Tst',
	'Afick::Gen',
	'Afick::Directives',
	'Afick::Macros',
	'Afick::Aliases',
	'Afick::Cfg',

	#'Afick::Backend',
	#'Afick::Control',
	#'Afick::File',
	#'Afick::Plugins',
	#'Afick::Res',
);

foreach my $module (@modules) {
	## no critic (ProhibitStringyEval,RequireCheckingReturnValueOfEval)
	eval "require $module";
	if ($EVAL_ERROR) {
		die "CRITICAL : can not find $module : $EVAL_ERROR\n";
	}
	else {
		import $module;
	}
}
##########################################################################
# afick current version : to be common for afick and afick-tk
sub get_afick_version() {
	return '3.5.0';
}
##########################################################################

1;
